kuuko pushed a commit to branch master.

http://git.enlightenment.org/bindings/python/python-efl.git/commit/?id=724dedb0e2f3cd001d02a4cf2fdc75b235b1b26a

commit 724dedb0e2f3cd001d02a4cf2fdc75b235b1b26a
Author: Kai Huuhko <[email protected]>
Date:   Fri Dec 6 03:00:12 2013 +0200

    Documentation: Changed C API references into Python ones.
---
 efl/elementary/dayselector.pyx     |   9 ++-
 efl/elementary/entry.pyx           |  22 +++-----
 efl/elementary/fileselector.pyx    |   8 +--
 efl/elementary/flipselector.pyx    |  20 +++----
 efl/elementary/gengrid.pyx         |  14 ++---
 efl/elementary/gengrid_widget.pxi  |   4 +-
 efl/elementary/genlist.pyx         | 110 ++++++++++++++++++-------------------
 efl/elementary/genlist_item.pxi    |   2 +-
 efl/elementary/genlist_widget.pxi  |   8 +--
 efl/elementary/index.pyx           |   9 ++-
 efl/elementary/layout_class.pyx    |   2 +-
 efl/elementary/object.pyx          |   6 +-
 efl/elementary/segment_control.pyx |   6 +-
 efl/elementary/transit.pyx         |   2 +-
 efl/elementary/web.pyx             |  33 ++++++-----
 15 files changed, 123 insertions(+), 132 deletions(-)

diff --git a/efl/elementary/dayselector.pyx b/efl/elementary/dayselector.pyx
index d080678..a0713f1 100644
--- a/efl/elementary/dayselector.pyx
+++ b/efl/elementary/dayselector.pyx
@@ -50,9 +50,9 @@ responsibility to set the styles again by sending 
corresponding signals.
 "day6" indicates the Saturday part name.
 
 Application can change individual day display string by using the API
-:py:meth:`efl.elementary.object.Object.part_text_set`.
+:py:meth:`~efl.elementary.object.Object.part_text_set`.
 
-:py:meth:`efl.elementary.object.Object.part_content_set` API sets the
+:py:meth:`~efl.elementary.object.Object.part_content_set` API sets the
 individual day object only if the passed one is a Check widget.
 
 Check object representing a day can be set/get by the application by using
@@ -60,7 +60,7 @@ the elm_object_part_content_set/get APIs thus providing a way 
to handle
 the different check styles for individual days.
 
 This widget emits the following signals, besides the ones sent from
-:py:class:`efl.elementary.layout_class.LayoutClass`:
+:py:class:`~efl.elementary.layout_class.LayoutClass`:
 
 - ``"dayselector,changed"`` - when the user changes the state of a day.
 - ``"language,changed"`` - the program's language changed
@@ -213,8 +213,7 @@ cdef class Dayselector(LayoutClass):
             dayselector.weekdays_names = ["Sunday", "Monday", "Tuesday",
                 "Wednesday", "Thursday", "Friday", "Saturday"]
 
-        :see: elm_dayselector_weekdays_name_get()
-        :see: elm_dayselector_weekend_start_set()
+        :see: :py:attr:`weekend_start`
 
         :since: 1.8
 
diff --git a/efl/elementary/entry.pyx b/efl/elementary/entry.pyx
index d52f16d..6d9045e 100644
--- a/efl/elementary/entry.pyx
+++ b/efl/elementary/entry.pyx
@@ -938,10 +938,6 @@ cdef class Entry(Object):
         a string in markup format. None is returned if no selection exists or
         if an error occurred.
 
-        The returned value points to an internal string and should not be freed
-        or modified in any way. If the ``entry`` object is deleted or its
-        contents are changed, the returned pointer should be considered 
invalid.
-
         :type: string
 
         """
@@ -1395,13 +1391,11 @@ cdef class Entry(Object):
         Append a markup filter function for text inserted in the entry
 
         Append the given callback to the list. This functions will be called
-        whenever any text is inserted into the entry, with the text to be 
inserted
-        as a parameter. The type of given text is always markup.
-        The callback function is free to alter the text in any way it wants, 
but
-        it must remember to free the given pointer and update it.
-        If the new text is to be discarded, the function can free it and set 
its
-        text parameter to NULL. This will also prevent any following filters 
from
-        being called.
+        whenever any text is inserted into the entry, with the text to be
+        inserted as a parameter. The type of given text is always markup. The
+        callback function is free to alter the text in any way it wants. If the
+        new text is to be discarded, the function can return None. This will
+        also prevent any following filters from being called.
 
         :param func: The function to use as text filter
         :param data: User data to pass to ``func``
@@ -1420,8 +1414,8 @@ cdef class Entry(Object):
 
         Prepend a markup filter function for text inserted in the entry
 
-        Prepend the given callback to the list. See 
elm_entry_markup_filter_append()
-        for more information
+        Prepend the given callback to the list. See
+        :py:meth:`markup_filter_append` for more information
 
         :param func: The function to use as text filter
         :param data: User data to pass to ``func``
@@ -1439,7 +1433,7 @@ cdef class Entry(Object):
         Remove a markup filter from the list
 
         Removes the given callback from the filter list. See
-        elm_entry_markup_filter_append() for more information.
+        :py:meth:`markup_filter_append` for more information
 
         :param func: The filter function to remove
         :param data: The user data passed when adding the function
diff --git a/efl/elementary/fileselector.pyx b/efl/elementary/fileselector.pyx
index 0e891a1..5db747f 100644
--- a/efl/elementary/fileselector.pyx
+++ b/efl/elementary/fileselector.pyx
@@ -53,7 +53,7 @@ This widget emits the following signals, besides the ones 
sent from
 
 - ``activated`` - the user activated a file. This can happen by
     double-clicking or pressing Enter key. (**event_info** is a
-    pointer to the activated file path)
+    string with the activated file path)
 - ``selected`` - the user has clicked on a file (when not in
     folders-only mode) or directory (when in folders-only mode)
 - ``directory,open`` - the list has been populated with new
@@ -299,7 +299,7 @@ cdef class Fileselector(LayoutClass):
     property selected_paths:
         """A list of selected paths in the file selector.
 
-        It returns a list of the selected paths. This list pointer is only 
valid
+        It returns a list of the selected paths. This list is only valid
         so long as the selection doesn't change (no items are selected or
         unselected, or unselected implicitly by deletion). The list contains
         strings. The order of the items in this list is the order which
@@ -392,7 +392,7 @@ cdef class Fileselector(LayoutClass):
     def callback_activated_add(self, func, *args, **kwargs):
         """the user activated a file. This can happen by
         double-clicking or pressing Enter key. (**event_info** is a
-        pointer to the activated file path)."""
+        string with the activated file path)."""
         self._callback_add_full("activated", _cb_string_conv, func,
             *args, **kwargs)
 
@@ -430,7 +430,7 @@ cdef class Fileselector(LayoutClass):
 
     def callback_done_add(self, func, *args, **kwargs):
         """The user has clicked on the "ok" or "cancel" buttons
-        (*event_info* is a pointer to the selection's path)."""
+        (*event_info* is a string with the selection's path)."""
         self._callback_add_full("done", _cb_string_conv,
                                 func, *args, **kwargs)
 
diff --git a/efl/elementary/flipselector.pyx b/efl/elementary/flipselector.pyx
index 14a6ecb..c692774 100644
--- a/efl/elementary/flipselector.pyx
+++ b/efl/elementary/flipselector.pyx
@@ -92,7 +92,7 @@ cdef class FlipSelectorItem(ObjectItem):
         """
 
         The widget's list of labels to show will be appended with the
-        given value. If the user wishes so, a callback function pointer
+        given value. If the user wishes so, a callback function
         can be passed, which will get called when this same item is
         selected.
 
@@ -329,11 +329,9 @@ cdef class FlipSelector(Object):
 
         This list is *not* to be modified in any way and must not be
         freed. Use the list members with functions like
-        elm_object_item_text_set(),
-        elm_object_item_text_get(),
-        elm_object_item_del(),
-        elm_flipselector_item_selected_get(),
-        elm_flipselector_item_selected_set().
+        :py:attr:`efl.elementary.object_item.ObjectItem.text`,
+        :py:meth:`efl.elementary.object_item.ObjectItem.delete`,
+        :py:attr:`FlipselectorItem.selected`.
 
         .. warning:: This list is only valid until ``obj`` object's internal
             items list is changed. It should be fetched again with another
@@ -350,8 +348,9 @@ cdef class FlipSelector(Object):
         """Get the first item in the given flip selector widget's list of
         items.
 
-        .. seealso:: :py:func:`item_append`
-        .. seealso:: :py:attr:`last_item`
+        .. seealso::
+            :py:func:`item_append`
+            :py:attr:`last_item`
 
         :type: :py:class:`FlipSelectorItem`
 
@@ -364,8 +363,9 @@ cdef class FlipSelector(Object):
         """Get the last item in the given flip selector widget's list of
         items.
 
-        .. seealso:: :py:func:`item_prepend`
-        .. seealso:: :py:attr:`first_item`
+        .. seealso::
+            :py:func:`item_prepend`
+            :py:attr:`first_item`
 
         :type: :py:class:`FlipSelectorItem`
 
diff --git a/efl/elementary/gengrid.pyx b/efl/elementary/gengrid.pyx
index 84b80bb..f4c4806 100644
--- a/efl/elementary/gengrid.pyx
+++ b/efl/elementary/gengrid.pyx
@@ -108,19 +108,19 @@ following members:
   the ``part`` one is the name string of one of the existing text parts
   in the Edje group implementing the item's theme. This function
   **must** return a strdup'()ed string, as the caller will free() it
-  when done. See #Elm_Gengrid_Item_Text_Get_Cb.
+  when done. See :py:meth:`GengridItem.text_get`.
 - ``func.content_get`` - This function is called when an item object is
   actually created. The ``data`` parameter will point to the same data
-  passed to elm_gengrid_item_append() and related item creation
+  passed to :py:meth:`GengridItem.append_to` and related item creation
   functions. The ``obj`` parameter is the gengrid object itself, while
   the ``part`` one is the name string of one of the existing (content)
   swallow parts in the Edje group implementing the item's theme. It must
   return ``None,`` when no content is desired, or a valid object handle,
   otherwise. The object will be deleted by the gengrid on its deletion
-  or when the item is "unrealized". See #Elm_Gengrid_Item_Content_Get_Cb.
+  or when the item is "unrealized". See :py:meth:`GengridItem.content_get`.
 - ``func.state_get`` - This function is called when an item object is
   actually created. The ``data`` parameter will point to the same data
-  passed to elm_gengrid_item_append() and related item creation
+  passed to :py:meth:`GengridItem.append_to` and related item creation
   functions. The ``obj`` parameter is the gengrid object itself, while
   the ``part`` one is the name string of one of the state parts in the
   Edje group implementing the item's theme. Return ``False`` for
@@ -133,7 +133,7 @@ following members:
   an item or elm_gengrid_clear() is called on the gengrid. This is
   intended for use when gengrid items are deleted, so any data attached
   to the item (e.g. its data parameter on creation) can be deleted. See
-  #Elm_Gengrid_Item_Del_Cb.
+  :py:meth:`GengridItem.delete`.
 
 Usage hints
 ===========
@@ -191,8 +191,8 @@ Smart events that you can add callbacks for are:
   has its implementing Evas object instantiated, de facto.
   ``event_info`` is the gengrid item that was created. The object
   may be deleted at any time, so it is highly advised to the
-  caller **not** to use the object pointer returned from
-  elm_gengrid_item_object_get(), because it may point to freed
+  caller **not** to use the object returned from
+  :py:attr:`GengridItem.object`, because it may point to freed
   objects.
 - ``unrealized`` - This is called when the implementing Evas
   object for this item is deleted. ``event_info`` is the gengrid
diff --git a/efl/elementary/gengrid_widget.pxi 
b/efl/elementary/gengrid_widget.pxi
index 28239cf..8295856 100644
--- a/efl/elementary/gengrid_widget.pxi
+++ b/efl/elementary/gengrid_widget.pxi
@@ -625,8 +625,8 @@ cdef class Gengrid(Object):
         has its implementing Evas object instantiated, de facto.
         ``event_info`` is the gengrid item that was created. The object
         may be deleted at any time, so it is highly advised to the
-        caller **not** to use the object pointer returned from
-        elm_gengrid_item_object_get(), because it may point to freed
+        caller **not** to use the object returned from
+        :py:attr:`GengridItem.object`, because it may point to freed
         objects."""
         self._callback_add_full("realized", _cb_object_item_conv,
                                 func, *args, **kwargs)
diff --git a/efl/elementary/genlist.pyx b/efl/elementary/genlist.pyx
index 5bb4b10..0a98ac7 100644
--- a/efl/elementary/genlist.pyx
+++ b/efl/elementary/genlist.pyx
@@ -44,7 +44,7 @@ multiple different items with different classes, states and 
styles).
 Genlist will call the functions in this struct (methods) when an item is
 "realized" (i.e., created dynamically, while the user is scrolling the
 grid). All objects will simply be deleted when no longer needed with
-evas_object_del(). The #Elm_Genlist_Item_Class structure contains the
+:py:meth:`~efl.evas.Object.delete`. :py:class:`GenlistItemClass` contains the
 following members:
 
 - ``item_style`` - This is a constant string and simply defines the name
@@ -53,42 +53,41 @@ following members:
 - ``decorate_item_style`` - This is a constant string and simply defines
   the name of the decorate mode item style. It is used to specify
   decorate mode item style. It can be used when you call
-  elm_genlist_item_decorate_mode_set().
+  :py:attr:`GenlistItem.decorate_mode`.
 - ``decorate_all_item_style`` - This is a constant string and simply
   defines the name of the decorate all item style. It is used to specify
   decorate all item style. It can be used to set selection, checking and
   deletion mode. This is used when you call
-  elm_genlist_decorate_mode_set().
+  :py:attr:`Genlist.decorate_mode`.
 - ``func`` - A struct with pointers to functions that will be called when
   an item is going to be actually created. All of them receive a ``data``
   parameter that will point to the same data passed to
-  elm_genlist_item_append() and related item creation functions, and an
+  :py:meth:`GenlistItem.append_to` and related item creation functions, and an
   ``obj`` parameter that points to the genlist object itself.
 
-The function pointers inside ``func`` are ``text_get,`` ``content_get,``
-``state_get`` and ``del.`` The 3 first functions also receive a ``part``
+The function pointers inside ``func`` are ``text_get``, ``content_get``,
+``state_get`` and ``del``. The 3 first functions also receive a ``part``
 parameter described below. A brief description of these functions follows:
 
 - ``text_get`` - The ``part`` parameter is the name string of one of the
   existing text parts in the Edje group implementing the item's theme.
-  This function **must** return a strdup'()ed string, as the caller will
-  free() it when done. See #Elm_Genlist_Item_Text_Get_Cb.
+  See :py:meth:`GenlistItemClass.text_get`.
 - ``content_get`` - The ``part`` parameter is the name string of one of the
   existing (content) swallow parts in the Edje group implementing the
   item's theme. It must return ``None``, when no content is desired, or
   a valid object handle, otherwise.  The object will be deleted by the
   genlist on its deletion or when the item is "unrealized". See
-  #Elm_Genlist_Item_Content_Get_Cb.
+  :py:meth:`GenlistItemClass.content_get`.
 - ``func.state_get`` - The ``part`` parameter is the name string of one of
   the state parts in the Edje group implementing the item's theme. Return
   ``False`` for false/off or ``True`` for true/on. Genlists will
   emit a signal to its theming Edje object with ``"elm,state,xxx,active"``
   and ``"elm"`` as "emission" and "source" arguments, respectively, when
   the state is true (the default is false), where ``xxx`` is the name of
-  the (state) part.  See #Elm_Genlist_Item_State_Get_Cb.
+  the (state) part.  See :py:meth:`GenlistItemClass.state_get`.
 - ``func.del`` - This is intended for use when genlist items are deleted,
   so any data attached to the item (e.g. its data parameter on creation)
-  can be deleted. See #Elm_Genlist_Item_Del_Cb.
+  can be deleted. See :py:meth:`GenlistItemClass.delete`.
 
 Available item styles:
 
@@ -111,12 +110,12 @@ more contents (which are simply objects swallowed into 
the genlist item's
 theming Edje object) and 0 or more **boolean states**, which have the
 behavior left to the user to define. The Edje part names for each of
 these properties will be looked up, in the theme file for the genlist,
-under the Edje (string) data items named ``"labels",`` ``"contents"``
-and ``"states",`` respectively. For each of those properties, if more
+under the Edje (string) data items named ``labels``, ``contents``
+and ``states``, respectively. For each of those properties, if more
 than one part is provided, they must have names listed separated by
 spaces in the data fields. For the default genlist item theme, we have
-**one** text part (``"elm.text"),`` **two** content parts
-(``"elm.swallow.icon"`` and ``"elm.swallow.end")`` and **no** state parts.
+**one** text part (``elm.text``), **two** content parts
+(``elm.swallow.icon`` and ``elm.swallow.end``) and **no** state parts.
 
 A genlist item may be at one of several styles. Elementary provides one
 by default - "default", but this can be extended by system or application
@@ -141,25 +140,26 @@ a convenience callback that is called when the item is 
selected and the
 data parameter will be the func_data parameter, ``obj`` be the genlist
 object and event_info will be the genlist item.
 
-elm_genlist_item_append() adds an item to the end of the list, or if
+:py:meth:`GenlistItem.append_to` adds an item to the end of the list, or if
 there is a parent, to the end of all the child items of the parent.
-elm_genlist_item_prepend() is the same but adds to the beginning of
-the list or children list. elm_genlist_item_insert_before() inserts at
-item before another item and elm_genlist_item_insert_after() inserts after
+:py:meth:`GenlistItem.prepend_to` is the same but adds to the beginning of
+the list or children list. :py:meth:`GenlistItem.insert_before` inserts at
+item before another item and :py:meth:`GenlistItem.insert_after` inserts after
 the indicated item.
 
-The application can clear the list with elm_genlist_clear() which deletes
-all the items in the list and elm_object_item_del() will delete a specific
-item. elm_genlist_item_subitems_clear() will clear all items that are
+The application can clear the list with :py:meth:`Genlist.clear` which deletes
+all the items in the list and
+:py:meth:`~efl.elementary.object_item.ObjectItem.delete` will delete a specific
+item. :py:meth:`GenlistItem.subitems_clear` will clear all items that are
 children of the indicated parent item.
 
 To help inspect list items you can jump to the item at the top of the list
-with elm_genlist_first_item_get() which will return the item pointer, and
-similarly elm_genlist_last_item_get() gets the item at the end of the list.
-elm_genlist_item_next_get() and elm_genlist_item_prev_get() get the next
+with :py:attr:`Genlist.first_item` which will return the item pointer, and
+similarly :py:attr:`Genlist.last_item` gets the item at the end of the list.
+:py:attr:`GenlistItem.next` and :py:attr:`GenlistItem.prev` get the next
 and previous items respectively relative to the indicated item. Using
 these calls you can walk the entire item list/tree. Note that as a tree
-the items are flattened in the list, so elm_genlist_item_parent_get() will
+the items are flattened in the list, so :py:attr:`GenlistItem.parent` will
 let you know which item is the parent (and thus know how to skip them if
 wanted).
 
@@ -167,37 +167,36 @@ Multi-selection
 ===============
 
 If the application wants multiple items to be able to be selected,
-elm_genlist_multi_select_set() can enable this. If the list is
-single-selection only (the default), then elm_genlist_selected_item_get()
+:py:attr:`Genlist.multi_select` can enable this. If the list is
+single-selection only (the default), then :py:attr:`Genlist.selected_item`
 will return the selected item, if any, or None if none is selected. If the
-list is multi-select then elm_genlist_selected_items_get() will return a
+list is multi-select then :py:attr:`Genlist.selected_items` will return a
 list (that is only valid as long as no items are modified (added, deleted,
 selected or unselected)).
 
 Usage hints
 ===========
 
-There are also convenience functions. elm_object_item_widget_get() will
-return the genlist object the item belongs to. elm_genlist_item_show()
-will make the scroller scroll to show that specific item so its visible.
-elm_object_item_data_get() returns the data pointer set by the item
-creation functions.
+There are also convenience functions.
+:py:attr:`efl.elementary.object_item.ObjectItem.widget` will return the genlist
+object the item belongs to. :py:meth:`GenlistItem.show` will make the scroller
+scroll to show that specific item so its visible.
+:py:attr:`efl.elementary.object_item.ObjectItem.data` returns the data pointer
+set by the item creation functions.
 
 If an item changes (state of boolean changes, text or contents change),
-then use elm_genlist_item_update() to have genlist update the item with
+then use :py:meth:`GenlistItem.update` to have genlist update the item with
 the new state. Genlist will re-realize the item and thus call the functions
 in the _Elm_Genlist_Item_Class for that item.
 
-To programmatically (un)select an item use elm_genlist_item_selected_set().
-To get its selected state use elm_genlist_item_selected_get(). Similarly
-to expand/contract an item and get its expanded state, use
-elm_genlist_item_expanded_set() and elm_genlist_item_expanded_get(). And
-again to make an item disabled (unable to be selected and appear
-differently) use elm_object_item_disabled_set() to set this and
-elm_object_item_disabled_get() to get the disabled state.
+Use :py:attr:`GenlistItem.selected` to programmatically (un)select an item or
+get its selected state. Similarly to expand/contract an item and get its
+expanded state, use :py:attr:`GenlistItem.expanded`. And again to make an item
+disabled (unable to be selected and appear differently) use
+:py:attr:`GenlistItem.disabled` to set this and get the disabled state.
 
 In general to indicate how the genlist should expand items horizontally to
-fill the list area, use elm_genlist_mode_set(). Valid modes are
+fill the list area, use :py:attr:`Genlist.mode`. Valid modes are
 ELM_LIST_LIMIT, ELM_LIST_COMPRESS and ELM_LIST_SCROLL. The default is
 ELM_LIST_SCROLL. This mode means that if items are too wide to fit, the
 scroller will scroll horizontally. Otherwise items are expanded to
@@ -210,16 +209,17 @@ that uses edjes' ellipsis feature (cutting text off like 
this: "tex...").
 
 Items will only call their selection func and callback when first becoming
 selected. Any further clicks will do nothing, unless you enable always
-select with elm_genlist_select_mode_set() as ELM_OBJECT_SELECT_MODE_ALWAYS.
+select with :py:attr:`Genlist.select_mode` as ELM_OBJECT_SELECT_MODE_ALWAYS.
 This means even if selected, every click will make the selected callbacks
-be called. elm_genlist_select_mode_set() as ELM_OBJECT_SELECT_MODE_NONE will
+be called. :py:attr:`Genlist.select_mode` as ELM_OBJECT_SELECT_MODE_NONE will
 turn off the ability to select items entirely and they will neither
 appear selected nor call selected callback functions.
 
-Remember that you can create new styles and add your own theme augmentation
-per application with elm_theme_extension_add(). If you absolutely must
-have a specific style that overrides any theme the user or system sets up
-you can use elm_theme_overlay_add() to add such a file.
+Remember that you can create new styles and add your own theme augmentation per
+application with :py:meth:`efl.elementary.theme.Theme.extension_add`. If you
+absolutely must have a specific style that overrides any theme the user or
+system sets up you can use :py:meth:`efl.elementary.theme.Theme.overlay_add` to
+add such a file.
 
 Scrollable Interface
 ====================
@@ -281,23 +281,23 @@ Signals that you can add callbacks for are:
 - ``"unselected"`` - This is called when a user has made an item
   unselected. The event_info parameter is the genlist item that was
   unselected.
-- ``"expanded"`` - This is called when elm_genlist_item_expanded_set() is
+- ``"expanded"`` - This is called when :py:attr:`GenlistItem.expanded` is
   called and the item is now meant to be expanded. The event_info
   parameter is the genlist item that was indicated to expand.  It is the
   job of this callback to then fill in the child items.
-- ``"contracted"`` - This is called when elm_genlist_item_expanded_set() is
+- ``"contracted"`` - This is called when :py:attr:`GenlistItem.expanded` is
   called and the item is now meant to be contracted. The event_info
   parameter is the genlist item that was indicated to contract. It is the
   job of this callback to then delete the child items.
 - ``"expand,request"`` - This is called when a user has indicated they want
   to expand a tree branch item. The callback should decide if the item can
-  expand (has any children) and then call elm_genlist_item_expanded_set()
+  expand (has any children) and then call :py:attr:`GenlistItem.expanded`
   appropriately to set the state. The event_info parameter is the genlist
   item that was indicated to expand.
 - ``"contract,request"`` - This is called when a user has indicated they
   want to contract a tree branch item. The callback should decide if the
   item can contract (has any children) and then call
-  elm_genlist_item_expanded_set() appropriately to set the state. The
+  :py:attr:`GenlistItem.expanded` appropriately to set the state. The
   event_info parameter is the genlist item that was indicated to contract.
 - ``"realized"`` - This is called when the item in the list is created as a
   real evas object. event_info parameter is the genlist item that was
@@ -351,11 +351,11 @@ Signals that you can add callbacks for are:
 - ``"moved"`` - This is called when a genlist item is moved in reorder mode.
 - ``"moved,after"`` - This is called when a genlist item is moved after
   another item in reorder mode. The event_info parameter is the reordered
-  item. To get the relative previous item, use elm_genlist_item_prev_get().
+  item. To get the relative previous item, use :py:attr:`GenlistItem.prev`.
   This signal is called along with "moved" signal.
 - ``"moved,before"`` - This is called when a genlist item is moved before
   another item in reorder mode. The event_info parameter is the reordered
-  item. To get the relative previous item, use elm_genlist_item_next_get().
+  item. To get the relative previous item, use :py:attr:`GenlistItem.next`.
   This signal is called along with "moved" signal.
 - ``"language,changed"`` - This is called when the program's language is
   changed.
diff --git a/efl/elementary/genlist_item.pxi b/efl/elementary/genlist_item.pxi
index d6dd279..54cdbab 100644
--- a/efl/elementary/genlist_item.pxi
+++ b/efl/elementary/genlist_item.pxi
@@ -604,7 +604,7 @@ cdef class GenlistItem(ObjectItem):
 
         The theme will respond to this change visually, and a signal
         "expanded" or "contracted" will be sent from the genlist with a
-        pointer to the item that has been expanded/contracted.
+        the item that has been expanded/contracted.
 
         Calling this function won't show or hide any child of this item (if
         it is a parent). You must manually delete and create them on the
diff --git a/efl/elementary/genlist_widget.pxi 
b/efl/elementary/genlist_widget.pxi
index 5287f0d..9567a68 100644
--- a/efl/elementary/genlist_widget.pxi
+++ b/efl/elementary/genlist_widget.pxi
@@ -322,15 +322,15 @@ cdef class Genlist(Object):
         return _object_item_to_python(elm_genlist_selected_item_get(self.obj))
 
     property selected_items:
-        """It returns a list of the selected items. This list pointer is
+        """It returns a list of the selected items. This list is
         only valid so long as the selection doesn't change (no items are
         selected or unselected, or unselected implicitly by deletion). The
-        list contains genlist items pointers. The order of the items in this
+        list contains genlist items. The order of the items in this
         list is the order which they were selected, i.e. the first item in
         this list is the first item that was selected, and so on.
 
         .. note:: If not in multi-select mode, consider using function
-            elm_genlist_selected_item_get() instead.
+            :py:attr:`Genlist.selected_item` instead.
 
         .. seealso:: :py:attr:`multi_select` :py:attr:`selected_item`
 
@@ -345,7 +345,7 @@ cdef class Genlist(Object):
 
     property realized_items:
         """This returns a list of the realized items in the genlist. The list
-        contains genlist item pointers. The list must be freed by the
+        contains genlist items. The list must be freed by the
         caller when done with eina_list_free(). The item pointers in the
         list are only valid so long as those items are not deleted or the
         genlist is not deleted.
diff --git a/efl/elementary/index.pyx b/efl/elementary/index.pyx
index d43b0d9..99c12bb 100644
--- a/efl/elementary/index.pyx
+++ b/efl/elementary/index.pyx
@@ -45,13 +45,12 @@ This widget emits the following signals, besides the ones 
sent from
 :py:class:`~efl.elementary.layout_class.LayoutClass`:
 
 - ``"changed"`` - When the selected index item changes. ``event_info``
-  is the selected item's data pointer.
+  is the selected item's data.
 - ``"delay,changed"`` - When the selected index item changes, but
   after a small idling period. ``event_info`` is the selected
-  item's data pointer.
+  item's data.
 - ``"selected"`` - When the user releases a mouse button and
-  selects an item. ``event_info`` is the selected item's data
-  pointer.
+  selects an item. ``event_info`` is the selected item's data.
 - ``"level,up"`` - when the user moves a finger from the first
   level to the second level
 - ``"level,down"`` - when the user moves a finger from the second
@@ -289,7 +288,7 @@ cdef class IndexItem(ObjectItem):
             data item should be pointed to by the index item in question,
             ``cmp_data_func`` will be used. If ``cmp_data_func`` returns a
             non-negative value, the previous index item data will be
-            replaced by the given ``item`` pointer. If the previous data need
+            replaced by the given ``item``. If the previous data need
             to be freed, it should be done by the ``cmp_data_func``
             function, because all references to it will be lost. If this
             function is not provided (``None`` is given), index items will
diff --git a/efl/elementary/layout_class.pyx b/efl/elementary/layout_class.pyx
index f1a817a..940f37d 100644
--- a/efl/elementary/layout_class.pyx
+++ b/efl/elementary/layout_class.pyx
@@ -315,7 +315,7 @@ cdef class LayoutClass(Object):
         emitted by the undelying Edje object, with parameters *emission*,
         ``source`` and ``func`` matching exactly those passed to a previous
         call to :py:meth:`~efl.elementary.object.Object.signal_callback_add`.
-        The data pointer that was passed to this call will be returned.
+        The data that was passed to this call will be returned.
 
         :param emission: The signal's name string
         :type emission: string
diff --git a/efl/elementary/object.pyx b/efl/elementary/object.pyx
index a8f78b9..002c89e 100644
--- a/efl/elementary/object.pyx
+++ b/efl/elementary/object.pyx
@@ -753,7 +753,7 @@ cdef class Object(evasObject):
 
         - Just return ``True`` on *func*. ``False`` will mean the event
             was **not** processed, so the propagation will go on.
-        - The ``event_info`` pointer passed to ``func`` will contain the
+        - The ``event_info`` passed to ``func`` will contain the
             event's structure and, if you OR its ``event_flags`` inner
             value to *EVAS_EVENT_FLAG_ON_HOLD*, you're telling
             Elementary one has already handled it, thus killing the
@@ -1802,7 +1802,7 @@ cdef class Object(evasObject):
         :param selection: Selection type for copying and pasting
         :param format: Selection format
         :param datacb: The user data callback if the target widget isn't 
elm_entry
-        :param udata: The user data pointer for ``datacb``
+        :param udata: The user data for ``datacb``
 
         :return bool: Whether getting cnp data was successful or not.
 
@@ -1847,7 +1847,7 @@ cdef class Object(evasObject):
 
         :param selection: Selection to be notified of for loss
         :param func: The function to call
-        :param data: The data pointer passed to the function.
+        :param data: The data passed to the function.
 
         """
         if not callable(func):
diff --git a/efl/elementary/segment_control.pyx 
b/efl/elementary/segment_control.pyx
index 9ab2380..8f27090 100644
--- a/efl/elementary/segment_control.pyx
+++ b/efl/elementary/segment_control.pyx
@@ -37,7 +37,7 @@ This widget emits the following signals, besides the ones 
sent from
 
 - ``"changed"`` - When the user clicks on a segment item which is not
   previously selected and get selected. The event_info parameter is the
-  segment item pointer.
+  segment item.
 
 Available styles for it:
 
@@ -270,7 +270,7 @@ cdef class SegmentControl(LayoutClass):
 
         Get the label of item.
 
-        The return value is a pointer to the label associated to the item when
+        The return value is the label associated to the item when
         it was created, with function :py:meth:`item_add`, or later with
         function :py:attr:`~efl.elementary.object_item.ObjectItem.text`. If no
         label was passed as argument, it will return ``None``.
@@ -288,7 +288,7 @@ cdef class SegmentControl(LayoutClass):
 
         Get the icon associated to the item.
 
-        The return value is a pointer to the icon associated to the item when 
it
+        The return value is the icon associated to the item when it
         was created, with function :py:meth:`item_add`, or later with function
         :py:meth:`~efl.elementary.object_item.ObjectItem.part_content_set`. If
         no icon was passed as argument, it will return ``None``.
diff --git a/efl/elementary/transit.pyx b/efl/elementary/transit.pyx
index a5d9661..e41d8dc 100644
--- a/efl/elementary/transit.pyx
+++ b/efl/elementary/transit.pyx
@@ -438,7 +438,7 @@ cdef class Transit(object):
         .. note:: the ``transit`` object will be deleted after call ``func``
             function.
 
-        :param func: Callback function pointer. This function will be called
+        :param func: Callback function. This function will be called
             before the deletion of the transit.
         :param data: Callback function user data. It is the ``op`` parameter.
 
diff --git a/efl/elementary/web.pyx b/efl/elementary/web.pyx
index 99f60ce..f8c1a9d 100644
--- a/efl/elementary/web.pyx
+++ b/efl/elementary/web.pyx
@@ -25,7 +25,7 @@ ewebkit support.
 Signals that you can add callbacks for are:
 
 - "download,request": A file download has been requested. Event info is
-  a pointer to a Elm_Web_Download
+  a WebDownload instance
 - "editorclient,contents,changed": Editor client's contents changed
 - "editorclient,selection,changed": Editor client's selection changed
 - "frame,created": A new frame was created. Event info is an
@@ -40,41 +40,40 @@ Signals that you can add callbacks for are:
 - "link,hover,out": Mouse cursor left the link
 - "load,document,finished": Loading of a document finished. Event info
   is the frame that finished loading
-- "load,error": Load failed. Event info is a pointer to
-  Elm_Web_Frame_Load_Error
-- "load,finished": Load finished. Event info is NULL on success, on
-  error it's a pointer to Elm_Web_Frame_Load_Error
+- "load,error": Load failed. Event info is a WebFrameLoadError instance
+- "load,finished": Load finished. Event info is None on success, on
+  error it's a WebFrameLoadError instance
 - "load,newwindow,show": A new window was created and is ready to be
   shown
-- "load,progress": Overall load progress. Event info is a pointer to
+- "load,progress": Overall load progress. Event info is
   a double containing a value between 0.0 and 1.0
 - "load,provisional": Started provisional load
 - "load,started": Loading of a document started
 - "menubar,visible,get": Queries if the menubar is visible. Event info
-  is a pointer to Eina_Bool where the callback should set EINA_TRUE if
-  the menubar is visible, or EINA_FALSE in case it's not
+  is a bool where the callback should set True if
+  the menubar is visible, or False in case it's not
 - "menubar,visible,set": Informs menubar visibility. Event info is
-  an Eina_Bool indicating the visibility
+  a bool indicating the visibility
 - "popup,created": A dropdown widget was activated, requesting its
   popup menu to be created. Event info is a pointer to Elm_Web_Menu
 - "popup,willdelete": The web object is ready to destroy the popup
   object created. Event info is a pointer to Elm_Web_Menu
 - "ready": Page is fully loaded
 - "scrollbars,visible,get": Queries visibility of scrollbars. Event
-  info is a pointer to Eina_Bool where the visibility state should be set
+  info is a bool where the visibility state should be set
 - "scrollbars,visible,set": Informs scrollbars visibility. Event info
   is an Eina_Bool with the visibility state set
-- "statusbar,text,set": Text of the statusbar changed. Even info is
+- "statusbar,text,set": Text of the statusbar changed. Event info is
   a string with the new text
 - "statusbar,visible,get": Queries visibility of the status bar.
-  Event info is a pointer to Eina_Bool where the visibility state should be
+  Event info is a bool where the visibility state should be
   set.
 - "statusbar,visible,set": Informs statusbar visibility. Event info is
   an Eina_Bool with the visibility value
 - "title,changed": Title of the main frame changed. Event info is a
   string with the new title
 - "toolbars,visible,get": Queries visibility of toolbars. Event info
-  is a pointer to Eina_Bool where the visibility state should be set
+  is a bool where the visibility state should be set
 - "toolbars,visible,set": Informs the visibility of toolbars. Event
   info is an Eina_Bool with the visibility state
 - "tooltip,text,set": Show and set text of a tooltip. Event info is
@@ -1005,7 +1004,7 @@ cdef class Web(Object):
     #     self._callback_del("load,document,finished", func)
 
     def callback_load_error_add(self, func, *args, **kwargs):
         """Load failed. Event info is a pointer to Elm_Web_Frame_Load_Error."""
         self._callback_add_full("load,error", _web_load_frame_error_conv, func,
             *args, **kwargs)
 
@@ -1029,7 +1028,7 @@ cdef class Web(Object):
         self._callback_del("load,newwindow,show", func)
 
     def callback_load_progress_add(self, func, *args, **kwargs):
-        """Overall load progress. Event info is a pointer to a double 
containing
+        """Overall load progress. Event info is a double containing
         a value between 0.0 and 1.0."""
         self._callback_add_full("load,progress", _web_double_conv, func,
             *args, **kwargs)
@@ -40,41 +40,40 @@ Signals that you can add callbacks for are:
 - "popup,created": A dropdown widget was activated, requesting its
-  popup menu to be created. Event info is a pointer to Elm_Web_Menu
+  popup menu to be created. Event info is a WebMenu instance
 - "popup,willdelete": The web object is ready to destroy the popup
@@ -40,41 +40,40 @@ Signals that you can add callbacks for are:
 - "popup,willdelete": The web object is ready to destroy the popup
-  object created. Event info is a pointer to Elm_Web_Menu
+  object created. Event info is a WebMenu instance
 - "ready": Page is fully loaded
 - "scrollbars,visible,get": Queries visibility of scrollbars. Event
@@ -1005,7 +1004,7 @@ cdef class Web(Object):
 
     def callback_load_error_add(self, func, *args, **kwargs):
-        """Load failed. Event info is a pointer to Elm_Web_Frame_Load_Error."""
+        """Load failed. Event info is a WebFrameLoadError instance."""
         self._callback_add_full("load,error", _web_load_frame_error_conv, func,
             *args, **kwargs)

-- 


Reply via email to